@@ -52,4 +52,8 @@ class WinConst():
     ICON_BIG=1
     IMAGE_ICON = 1
     LR_CREATEDIBSECTION = 0x00002000
-    SRCCOPY = 13369376
\ No newline at end of file
+    SRCCOPY = 13369376
+    IDC_SIZENS=32645
+    IDC_SIZEWE=32644
+    IDC_SIZENWSE=32642
+    IDC_SIZENESW=32643
\ No newline at end of file
